==> lxqt-notificationd_0.14.1.orig.tar.xz: lxqt-notificationd-0.14.1/config/translations/lxqt-config-notificationd_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>宽度:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="32"/>
        <location filename="../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>间距:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>持续时间</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>有些通知有自己的持续时间。</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>默认持续时间:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="127"/>
        <source>Unattended Notifications</source>
        <translation>未读通知</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>How many to save:</source>
        <translation>要保存的数量：</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <location filename="../advancedsettings.ui" line="159"/>
        <source>Application name is on the top of notification.</source>
        <translation>应用程序名称位于通知顶部。</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="152"/>
        <source>Ignore these applications:</source>
        <translation>忽略这些应用程序：</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="162"/>
        <source>app1,app2,app3</source>
        <translation>程序1，程序2，程序3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>基本设置</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>在屏幕上的位置</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="56"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 没有运行通知守护进程
已使用默认值。</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="59"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 正在运行第三方的通知守护进程（%1）
这些设置不会有任何效果！</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="112"/>
        <source>Notification demo </source>
        <translation>通知示例 </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="113"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>这是一则测试通知
 LXQt 上的所有通知都会出现于此。</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>桌面通知</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Basic Settings</source>
        <translation>基本设置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Advanced Settings</source>
        <translation>高级设置</translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_0.16.0.orig.tar.xz: lxqt-notificationd-0.16.0/config/translations/lxqt-config-notificationd_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Sizes</source>
        <translation>大小</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="75"/>
        <source>Width:</source>
        <translation>宽度:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="82"/>
        <location filename="../advancedsettings.ui" line="106"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source>Spacing:</source>
        <translation>间距:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="118"/>
        <source>Duration</source>
        <translation>持续时间</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="130"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>有些通知有自己的持续时间。</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="142"/>
        <source>Default duration:</source>
        <translation>默认持续时间:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="177"/>
        <source>Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="183"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="186"/>
        <source>Show notifications on screen with the mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>未读通知</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>要保存的数量：</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>应用程序名称位于通知顶部。</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>忽略这些应用程序：</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>程序1，程序2，程序3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>基本设置</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>在屏幕上的位置</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="61"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="70"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 没有运行通知守护进程
已使用默认值。</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="73"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 正在运行第三方的通知守护进程（%1）
这些设置不会有任何效果！</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="131"/>
        <source>Notification demo </source>
        <translation>通知示例 </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="132"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>这是一则测试通知
 LXQt 上的所有通知都会出现于此。</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>桌面通知</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Basic Settings</source>
        <translation>基本设置</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Advanced Settings</source>
        <translation>高级设置</translation>
    </message>
</context>
</TS>
